@@ -1,20 +1,28 @@
 margins <-
 function(object, newdata) {
 
-#newdata debe ser el mismo que con el que se construye object
-#newdata must be the same used in object
+
+	#newdata must be the same used in object 
+
+	#Exigimos que object contenga votes y formula
+	
+	if ((is.null(object$votes)==TRUE)|(is.null(object$formula)==TRUE)
+	){
+	stop("object must have formula and votes in the output")
+}
+
 
 
 vardep <- newdata[,as.character(object$formula[[2]])]
 n <- length(newdata[,1])
 nclases <- nlevels(vardep)
-votos<- object[[4]]
+
 
 votos<- object$votes
 votos/apply(votos,1,sum)->votosporc
 
 
-margen<-rep(0,n) #Creo un vector para guardar los errores conforme evoluciona boosting
+margen<-rep(0,n) #Creo un vector para guardar los margenes de cada observacion
 
 for (i in 1:n) {
  
@@ -24,5 +32,8 @@ margen[i]<- min(k[k!=0])
 }
 
 output<- list( margins=margen)
+class(output) <- "margins"
+output
+
 }
 
